@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Finance::FXCM::Simple;
-$Finance::FXCM::Simple::VERSION = '0.013';
+$Finance::FXCM::Simple::VERSION = '0.014';
 require XSLoader;
 XSLoader::load(
     'Finance::FXCM::Simple',
@@ -13,7 +13,7 @@ use YAML::XS;
 sub getTrades {
     my ($self) = @_;
     my $trades = Load($self->getTradesAsYAML());
-    return $trades;
+    return defined($trades) ? $trades : [];
 }
 
 sub getTradesForSymbol {
@@ -24,8 +24,8 @@ sub getTradesForSymbol {
 
 sub getOffersHash {
     my ($self) = @_;
-    my $trades = Load($self->getOffersHashAsYAML());
-    return $trades;
+    my $offersHash = Load($self->getOffersHashAsYAML());
+    return $offersHash;
 }
 
 1;
@@ -134,7 +134,7 @@ The url to connect to, typically this will be 'http://www.fxcorporate.com/Hosts.
 
 =item C<getAsk($instrument)>
 
-Get current ask price of instrument.  Subscription status must be set, see L</"setSubscriptionStatus($instrument, $status)">
+Get current ask price of instrument.  This is the price you can buy at.  Subscription status must be set, see L</"setSubscriptionStatus($instrument, $status)">
 
 =over 16
 
@@ -146,7 +146,7 @@ The instrument to fetch ask price for.
 
 =item C<getBid($instrument)>
 
-Get current bid price of instrument.  Subscription status must be set, see L</"setSubscriptionStatus($instrument, $status)">
+Get current bid price of instrument.  This is the price you can sell at.  Subscription status must be set, see L</"setSubscriptionStatus($instrument, $status)">
 
 =over 16
 
